# Lyrics Translator

The `Lyrics Translator` downloads lyrics from genius and uses hugging face to translate the English lyrics into a target language.

To use the `Lyrics Translator` you will have to create an API Key from `genius` and add it to a `env` file:

https://docs.genius.com/#/getting-started-h1
